==> owncloud-10.2.0.zip: owncloud/apps/files_sharing/l10n/pt_PT.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "A partilha entre servidores não se encontra ativada neste servidor",
    "The mountpoint name contains invalid characters." : "O nome do ponto de montagem contém carateres inválidos.",
    "Not allowed to create a federated share with the same user server" : "Não é permitido criar uma partilha federada com o mesmo servidor de utilizador",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido ou não confiável",
    "Could not authenticate to remote share, password might be wrong" : "Não foi possível autenticar a partilha remota, a palavra-passe poderá estar errada",
    "Storage not valid" : "Armazenamento inválido",
    "Couldn't add remote share" : "Não foi possível adicionar a partilha remota",
    "Shared with you" : "Partilhado consigo ",
    "Shared with others" : "Partilhado com outros",
    "Shared by link" : "Partilhado por hiperligação",
    "Anonymous upload" : "Carregamento anónimo",
    "Click to select files or use drag & drop to upload" : "Clique para selecionar ficheiros ou arraste e solte para carregar",
    "Uploaded files" : "Ficheiros carregados",
    "Uploading..." : "A enviar...",
    "Nothing shared with you yet" : "Ainda não foi partilhado nada consigo",
    "Files and folders others share with you will show up here" : "Os ficheiros e pastas que os outros partilham consigo, serão mostrados aqui",
    "Nothing shared yet" : "Ainda não foi partilhado nada",
    "Files and folders you share will show up here" : "Os ficheiros e as pastas que partilha serão mostrados aqui",
    "No shared links" : "Sem hiperligações partilhadas",
    "Files and folders you share by link will show up here" : "Os ficheiros e as pastas que partilha com esta hiperligação, serão mostrados aqui",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Deseja adicionar a partilha remota {nome} de {proprietário}@{remoto}?",
    "Remote share" : "Partilha remota",
    "Remote share password" : "Palavra-passe da partilha remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar partilha remota",
    "You can upload into this folder" : "Pode enviar para esta pasta",
    "No ownCloud installation (7 or higher) found at {remote}" : "Não foi encontrada nenhuma instalação OwnCloud (7 ou superior) em {remote}",
    "Invalid ownCloud url" : "Url da ownCloud inválido",
    "Share" : "Partilhar",
    "No expiration date set" : "Nenhuma data de expiração definida",
    "Shared by" : "Partilhado por",
    "Sharing" : "Partilha",
    "Share API is disabled" : "A partilha de API está desativada",
    "Wrong share ID, share doesn't exist" : "Id. de partilha errada, a partilha não existe",
    "Could not delete share" : "Não foi possível eliminar a partilha",
    "Please specify a file or folder path" : "Por favor, especifique um ficheiro ou caminho de pasta",
    "Wrong path, file/folder doesn't exist" : "Caminho errado, ficheiro/pasta não existe",
    "Cannot remove all permissions" : "Não é possível remover todas as permissões",
    "Please specify a valid user" : "Por favor, especifique um utilizador válido",
    "Group sharing is disabled by the administrator" : "A partilha em grupo está desativada pelo administrador",
    "Please specify a valid group" : "Por favor, especifique um grupo válido",
    "Public link sharing is disabled by the administrator" : "A partilha da hiperligação pública está desativada pelo administrador",
    "Public upload disabled by the administrator" : "Envio público desativado pelo administrador",
    "Public upload is only possible for publicly shared folders" : "O envio público só é possível para as pastas partilhadas publicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "A partilha de %s falhou porque \"back end\" não permite partilhas do tipo %s",
    "Unknown share type" : "Tipo de partilha desconhecido",
    "Not a directory" : "Não é uma diretoria",
    "Could not lock path" : "Não foi possível bloquear o caminho",
    "Can't change permissions for public share links" : "Não é possível alterar as permissões para as hiperligações de partilha pública",
    "Wrong or no update parameter given" : "Parâmetro indicado errado ou desatualizado",
    "Cannot increase permissions" : "Não é possível incrementar as permissões",
    "A file or folder has been <strong>shared</strong>" : "Foi <strong>partilhado</strong> um ficheiro ou uma pasta",
    "A file or folder was shared from <strong>another server</strong>" : "Um ficheiro ou pasta foi partilhado a partir de <strong>outro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Foi  <strong>transferido</strong> um ficheiro ou uma pasta partilhada publicamente",
    "You received a new remote share %2$s from %1$s" : "Recebeu uma nova partilha remota %2$s de %1$s",
    "You received a new remote share from %s" : "Recebeu uma nova partilha remota de %s",
    "%1$s accepted remote share %2$s" : "%1$s aceitou a partilha remota %2$s",
    "%1$s declined remote share %2$s" : "%1$s rejeitou a partilha remota %2$s",
    "%1$s unshared %2$s from you" : "%1$s cancelou a partilha %2$s consigo",
    "Public shared folder %1$s was downloaded" : "Foi transferida a pasta %1$s partilhada publicamente",
    "Public shared file %1$s was downloaded" : "Foi transferido o ficheiro %1$s partilhado publicamente",
    "You shared %1$s with %2$s" : "Partilhou %1$s com %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s partilhou %1$s com %3$s",
    "You removed the share of %2$s for %1$s" : "Removeu a partilha de %2$s para %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s removeu a partilha de %3$s para %1$s",
    "You shared %1$s with group %2$s" : "Partilhou %1$s com o grupo %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s partilhou %1$s com o grupo %3$s",
    "You removed the share of group %2$s for %1$s" : "Removeu a partilha do grupo %2$s para %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s removeu a partilha do grupo %3$s para %1$s",
    "%2$s shared %1$s via link" : "%2$s partilhou %1$s via hiperligação",
    "You shared %1$s via link" : "Partilhou %1$s através de uma hiperligação",
    "You removed the public link for %1$s" : "Removeu a hiperligação pública para %1$s",
    "%2$s removed the public link for %1$s" : "%2$s removeu a hiperligação pública para %1$s",
    "Your public link for %1$s expired" : "A sua hiperligação pública para %1$s expirou",
    "The public link of %2$s for %1$s expired" : "A sua hiperligação pública de %2$s para %1$s expirou",
    "%2$s shared %1$s with you" : "%2$s partilhou %1$s consigo",
    "%2$s removed the share for %1$s" : "%2$s removeu a partilha para %1$s",
    "Downloaded via public link" : "Transferido via hiperligação pública",
    "Shared with %2$s" : "Partilhado com %2$s",
    "Shared with %3$s by %2$s" : "Partilhado com %3$s por %2$s",
    "Removed share for %2$s" : "Partilha removida para %2$s",
    "%2$s removed share for %3$s" : "%2$s removeu a partilha para %3$s",
    "Shared with group %2$s" : "Partilhado com o grupo %2$s",
    "Shared with group %3$s by %2$s" : "Partilhado com o grupo %3$s por %2$s",
    "Removed share of group %2$s" : "Partilha removida do grupo %2$s",
    "%2$s removed share of group %3$s" : "%2$s removeu a partilha do grupo %3$s",
    "Shared via link by %2$s" : "Partilhado via hiperligação por %2$s",
    "Shared via public link" : "Partilhado via hiperligação pública",
    "Removed public link" : "Hiperligação pública removida",
    "%2$s removed public link" : "%2$s removeu a hiperligação pública",
    "Public link expired" : "A hiperligação pública expirou",
    "Public link of %2$s expired" : "A  hiperligação pública de %2$s expirou",
    "Shared by %2$s" : "Partilhado por %2$s",
    "Shares" : "Partilhas",
    "This share is password-protected" : "Esta partilha está protegida por palavra-passe",
    "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
    "Password" : "Palavra-passe",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Name" : "Nome",
    "Share time" : "Hora da Partilha",
    "Expiration date" : "Data de expiração",
    "Sorry, this link doesn’t seem to work anymore." : "Desculpe, mas esta hiperligação parece já não estar a funcionar.",
    "Reasons might be:" : "As razões poderão ser:",
    "the item was removed" : "o item foi removido",
    "the link expired" : "a hiperligação expirou",
    "sharing is disabled" : "a partilha está desativada",
    "For more info, please ask the person who sent this link." : "Para mais informação, por favor, pergunte à pessoa que lhe enviou esta hiperligação.",
    "%s is publicly shared" : "%s está partilhado publicamente",
    "Add to your ownCloud" : "Adicionar à sua ownCloud",
    "Download" : "Transferir",
    "Download %s" : "Transferir %s",
    "Direct link" : "Hiperligação direta",
    "Pending" : "Pendente",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "Declined" : "Negado",
    "Public link" : "Hiperligação Pública"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files_sharing/l10n/pt_PT.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "A partilha entre servidores não se encontra ativada neste servidor",
    "The mountpoint name contains invalid characters." : "O nome do ponto de montagem contém carateres inválidos.",
    "Not allowed to create a federated share with the same user server" : "Não é permitido criar uma partilha federada com o mesmo servidor de utilizador",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido ou não confiável",
    "Could not authenticate to remote share, password might be wrong" : "Não foi possível autenticar a partilha remota, a palavra-passe poderá estar errada",
    "Storage not valid" : "Armazenamento inválido",
    "Couldn't add remote share" : "Não foi possível adicionar a partilha remota",
    "Shared with you" : "Partilhado consigo ",
    "Shared with others" : "Partilhado com outros",
    "Shared by link" : "Partilhado por hiperligação",
    "Anonymous upload" : "Envio anónimo",
    "Click to select files or use drag & drop to upload" : "Clique para selecionar ficheiros ou arraste e solte para carregar",
    "Uploaded files" : "Ficheiros enviados",
    "Uploading..." : "A enviar...",
    "Nothing shared with you yet" : "Ainda não foi partilhado nada consigo",
    "Files and folders others share with you will show up here" : "Os ficheiros e pastas que os outros partilham consigo, serão mostrados aqui",
    "Nothing shared yet" : "Ainda não foi partilhado nada",
    "Files and folders you share will show up here" : "Os ficheiros e as pastas que partilha serão mostrados aqui",
    "No shared links" : "Sem hiperligações partilhadas",
    "Files and folders you share by link will show up here" : "Os ficheiros e as pastas que partilha com esta hiperligação, serão mostrados aqui",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Deseja adicionar a partilha remota {nome} de {proprietário}@{remoto}?",
    "Remote share" : "Partilha remota",
    "Remote share password" : "Palavra-passe da partilha remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar partilha remota",
    "You can upload into this folder" : "Pode enviar para esta pasta",
    "No ownCloud installation (7 or higher) found at {remote}" : "Não foi encontrada nenhuma instalação OwnCloud (7 ou superior) em {remote}",
    "Invalid ownCloud url" : "Url da ownCloud inválido",
    "Share" : "Partilhar",
    "No expiration date set" : "Nenhuma data de expiração definida",
    "Declined" : "Negado",
    "Pending" : "Pendente",
    "Shared by" : "Partilhado por",
    "Sharing" : "Partilha",
    "A file or folder has been <strong>shared</strong>" : "Foi <strong>partilhado</strong> um ficheiro ou uma pasta",
    "A file or folder was shared from <strong>another server</strong>" : "Um ficheiro ou pasta foi partilhado a partir de <strong>outro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Foi  <strong>transferido</strong> um ficheiro ou uma pasta partilhada publicamente",
    "You received a new remote share %2$s from %1$s" : "Recebeu uma nova partilha remota %2$s de %1$s",
    "You received a new remote share from %s" : "Recebeu uma nova partilha remota de %s",
    "%1$s accepted remote share %2$s" : "%1$s aceitou a partilha remota %2$s",
    "%1$s declined remote share %2$s" : "%1$s rejeitou a partilha remota %2$s",
    "%1$s unshared %2$s from you" : "%1$s cancelou a partilha %2$s consigo",
    "Public shared folder %1$s was downloaded" : "Foi transferida a pasta %1$s partilhada publicamente",
    "Public shared file %1$s was downloaded" : "Foi transferido o ficheiro %1$s partilhado publicamente",
    "You shared %1$s with %2$s" : "Partilhou %1$s com %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s partilhou %1$s com %3$s",
    "You removed the share of %2$s for %1$s" : "Removeu a partilha de %2$s para %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s removeu a partilha de %3$s para %1$s",
    "You shared %1$s with group %2$s" : "Partilhou %1$s com o grupo %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s partilhou %1$s com o grupo %3$s",
    "You removed the share of group %2$s for %1$s" : "Removeu a partilha do grupo %2$s para %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s removeu a partilha do grupo %3$s para %1$s",
    "%2$s shared %1$s via link" : "%2$s partilhou %1$s via hiperligação",
    "You shared %1$s via link" : "Partilhou %1$s através de uma hiperligação",
    "You removed the public link for %1$s" : "Removeu a hiperligação pública para %1$s",
    "%2$s removed the public link for %1$s" : "%2$s removeu a hiperligação pública para %1$s",
    "Your public link for %1$s expired" : "A sua hiperligação pública para %1$s expirou",
    "The public link of %2$s for %1$s expired" : "A sua hiperligação pública de %2$s para %1$s expirou",
    "%2$s shared %1$s with you" : "%2$s partilhou %1$s consigo",
    "%2$s removed the share for %1$s" : "%2$s removeu a partilha para %1$s",
    "Downloaded via public link" : "Transferido via hiperligação pública",
    "Shared with %2$s" : "Partilhado com %2$s",
    "Shared with %3$s by %2$s" : "Partilhado com %3$s por %2$s",
    "Removed share for %2$s" : "Partilha removida para %2$s",
    "%2$s removed share for %3$s" : "%2$s removeu a partilha para %3$s",
    "Shared with group %2$s" : "Partilhado com o grupo %2$s",
    "Shared with group %3$s by %2$s" : "Partilhado com o grupo %3$s por %2$s",
    "Removed share of group %2$s" : "Partilha removida do grupo %2$s",
    "%2$s removed share of group %3$s" : "%2$s removeu a partilha do grupo %3$s",
    "Shared via link by %2$s" : "Partilhado via hiperligação por %2$s",
    "Shared via public link" : "Partilhado via hiperligação pública",
    "Removed public link" : "Hiperligação pública removida",
    "%2$s removed public link" : "%2$s removeu a hiperligação pública",
    "Public link expired" : "A hiperligação pública expirou",
    "Public link of %2$s expired" : "A  hiperligação pública de %2$s expirou",
    "Shared by %2$s" : "Partilhado por %2$s",
    "Shares" : "Partilhas",
    "Public link" : "Hiperligação Pública",
    "Share API is disabled" : "A partilha de API está desativada",
    "Wrong share ID, share doesn't exist" : "Id. de partilha errada, a partilha não existe",
    "Could not delete share" : "Não foi possível eliminar a partilha",
    "Please specify a file or folder path" : "Por favor, especifique um ficheiro ou caminho de pasta",
    "Wrong path, file/folder doesn't exist" : "Caminho errado, ficheiro/pasta não existe",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
    "Please specify a valid user" : "Por favor, especifique um utilizador válido",
    "Group sharing is disabled by the administrator" : "A partilha em grupo está desativada pelo administrador",
    "Please specify a valid group" : "Por favor, especifique um grupo válido",
    "Public link sharing is disabled by the administrator" : "A partilha da hiperligação pública está desativada pelo administrador",
    "Public upload disabled by the administrator" : "Envio público desativado pelo administrador",
    "Public upload is only possible for publicly shared folders" : "O envio público só é possível para as pastas partilhadas publicamente",
    "Sharing %s failed because the back end does not allow shares from type %s" : "A partilha de %s falhou porque \"back end\" não permite partilhas do tipo %s",
    "Unknown share type" : "Tipo de partilha desconhecido",
    "Not a directory" : "Não é uma diretoria",
    "Could not lock path" : "Não foi possível bloquear o caminho",
    "Can't change permissions for public share links" : "Não é possível alterar as permissões para as hiperligações de partilha pública",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "This share is password-protected" : "Esta partilha está protegida por palavra-passe",
    "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
    "Password" : "Palavra-passe",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Name" : "Nome",
    "Share time" : "Hora da Partilha",
    "Expiration date" : "Data de expiração",
    "Sorry, this link doesn’t seem to work anymore." : "Desculpe, mas esta hiperligação parece já não estar a funcionar.",
    "Reasons might be:" : "As razões poderão ser:",
    "the item was removed" : "o item foi removido",
    "the link expired" : "a hiperligação expirou",
    "sharing is disabled" : "a partilha está desativada",
    "For more info, please ask the person who sent this link." : "Para mais informação, por favor, pergunte à pessoa que lhe enviou esta hiperligação.",
    "%s is publicly shared" : "%s está partilhado publicamente",
    "Download" : "Transferir",
    "Download %s" : "Transferir %s",
    "Direct link" : "Hiperligação direta"
},
"nplurals=2; plural=(n != 1);");
